@@ -9,7 +9,8 @@ import requests
 from requests import Response
 
 from rowantree.auth.sdk import AuthenticateUserCommand, AuthenticateUserRequest, Token
-from rowantree.common.sdk import BaseModel, demand_env_var, demand_env_var_as_float
+from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
+from rowantree.contracts import BaseModel
 
 from ..contracts.dto.wrapped_request import WrappedRequest
 from ..contracts.exceeded_retry_count_error import ExceededRetryCountError
