@@ -2,9 +2,8 @@
 from starlette import status
 
 from rowantree.common.sdk import demand_env_var
-from rowantree.contracts import FeatureType
+from rowantree.contracts import UserFeatureState
 
-from ... import ActiveFeatureResponse
 from ...contracts.dto.request_status_codes import RequestStatusCodes
 from ...contracts.dto.wrapped_request import WrappedRequest
 from ...contracts.request_verb import RequestVerb
@@ -22,7 +21,7 @@ class UserFeatureActiveGetCommand(AbstractCommand):
         Executes the command.
     """
 
-    def execute(self, user_guid: str) -> FeatureType:
+    def execute(self, user_guid: str) -> UserFeatureState:
         """
         Executes the command.
 
@@ -33,8 +32,8 @@ class UserFeatureActiveGetCommand(AbstractCommand):
 
         Returns
         -------
-        user_feature: FeatureType
-            The active FeatureType.
+        user_feature: UserFeatureState
+            The active UserFeatureState.
         """
 
         request: WrappedRequest = WrappedRequest(
@@ -43,5 +42,4 @@ class UserFeatureActiveGetCommand(AbstractCommand):
             statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
         response: dict = self.wrapped_request(request=request)
-        active_feature_response: ActiveFeatureResponse = ActiveFeatureResponse.parse_obj(response)
-        return active_feature_response.active_feature
+        return UserFeatureState.parse_obj(response)
