@@ -1,6 +1,5 @@
 """ Merchant Transform Request Definition """
-from rowantree.common.sdk import BaseModel
-from rowantree.contracts import StoreType
+from rowantree.contracts import BaseModel, StoreType
 
 
 class MerchantTransformRequest(BaseModel):
@@ -13,4 +12,5 @@ class MerchantTransformRequest(BaseModel):
         The name of the store to transform.
     """
 
+    user_guid: str
     store_name: StoreType
